readable property
This is the readable public exposed signal. It is created by the Signal constructor and is used to access the signal's value and stream.
Implementation
late final ReadableSignal<T?> readable = ReadableSignal._(this);
This is the readable public exposed signal. It is created by the Signal constructor and is used to access the signal's value and stream.
late final ReadableSignal<T?> readable = ReadableSignal._(this);