Signal<T> class

Inheritance
Implementers

Constructors

Signal(T value)

Properties

attachedNode Node
latefinalinherited
controller StreamController<T>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
readable ReadableSignal<T>
This is the readable public exposed signal. It is created by the Signal constructor and is used to access the signal's value and stream.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>
no setterinherited
streamTriggerImmediatly Stream<T>
no setterinherited
unsafeValue ↔ T
getter/setter pairinherited
value ↔ T
getter/setter pairinherited-getter

Methods

dispose() → void
inherited
emit(T newValue) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited