NodeRegistry class

Constructors

NodeRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose<N extends Node>(N node) → void
disposeAll() → void
getByKey(Key key) Node?
Checks if a node with this exact runtimeKey already exists.
getByRuntimeType(Type type) Node?
Checks if a node with this exact runtimeType already exists.
getOrNull<N extends Node>({Key? key}) → N?
Looks up a node by type compatibility (supports interfaces).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<N extends Node>(N node) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited