BaseBridgeSignal<V> class abstract

Inheritance
Implementers

Constructors

BaseBridgeSignal()

Properties

attachedNode Node
latefinalinherited
controller StreamController<V>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
True if the signal has a value assigned.
no setterinherited
isDisposed bool
Returns true if this signal has already been disposed.
no setterinherited
readable ReadableSignal<V>
This is the readable public exposed signal. It is created by the Signal constructor and is used to access the signal's value and stream.
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<V>
no setterinherited
streamTriggerImmediatly Stream<V>
no setterinherited
unsafeValue ↔ V
getter/setter pairinherited
value ↔ V
getter/setter pairinherited

Methods

connect(InheritedTrinityScope scope) → void
dispose() → void
inherited
emit(V newValue) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited