operator []= method
Copies the internal map before mutating so it detects the new reference.
Implementation
@override
void operator []=(K key, V value) {
final copy = {..._internalMap};
copy[key] = value;
_emitMap(copy);
}
Copies the internal map before mutating so it detects the new reference.
@override
void operator []=(K key, V value) {
final copy = {..._internalMap};
copy[key] = value;
_emitMap(copy);
}