signals/signal library

Classes

BoolSignal
ComputedSignal<T, V>
ComputedSignalMany<V>
FutureSignal<T>
ProtectedSignal<T>
A signal that can be read from the outside, but can only be modified from the inside. It is used to wrap signals that are not meant to be modified by the outside world.
ReadableSignal<T>
This class is just a read-only "view". It does NOT extend BaseSignal to avoid inheriting internal behaviors, acting instead as a proxy to the original signal.
Signal<T>
StreamSignal<T>
StreamSignalWithInitialValue<T>