ComputedSignalMany<V> class

Inheritance

Constructors

ComputedSignalMany({required Set<BaseSignal> source, required V transform()})
A read-only signal whose value is derived from a set of signals.

Properties

attachedNode Node
latefinalinherited
controller StreamController<V>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasValue bool
True if the signal has a value assigned.
no setterinherited
isDisposed bool
Returns true if this signal has already been disposed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Set<BaseSignal>
final
stream Stream<V>
no setterinherited
streamTriggerImmediatly Stream<V>
no setterinherited
transform → V Function()
final
unsafeValue ↔ V
getter/setter pairinherited
value → V
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited