StreamSignalWithInitialValue<T> class

Inheritance

Constructors

StreamSignalWithInitialValue(Stream<T> _source, {required T initialValue})

Properties

attachedNode Node
latefinalinherited
controller StreamController<T>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
True if the signal has a value assigned.
no setterinherited
isDisposed bool
Returns true if this signal has already been disposed.
no setterinherited
rawValue → T
no setter
readable ReadableSignal<T>
This is the readable public exposed signal. It is created by the Signal constructor and is used to access the signal's value and stream.
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>
no setterinherited
streamTriggerImmediatly Stream<T>
no setterinherited
unsafeValue ↔ T
getter/setter pairinherited
value ↔ T
getter/setter pairinherited

Methods

dispose() → void
override
emit(T newValue) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited