NodeProvider<N extends NodeInterface> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- NodeProvider
Constructors
- NodeProvider({Key? key, required N create(), required Widget? child})
- Use this widget to create a node and provide it to the widget tree
- NodeProvider.builder({Key? key, required N create(), required Widget builder(BuildContext context, N node)?})
- You can use NodeProvider.builder if you need to build the widget tree and access directly to the node.
-
NodeProvider.many({Key? key, required List<
N Function()> nodes, required Widget? child}) -
const
- NodeProvider.reuse({Key? key, required N create(), required Widget builder(BuildContext context, N node)?})
- If the node you want to use might be created in a parent scope but you don't want to recreate it,use this constructor.
Properties
- builder → Widget Function(BuildContext context, N node)?
-
final
- child → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
nodes
→ List<
N Function()> -
final
- reuse → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< NodeProvider< N> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited