onInit property

void Function(N node)? onInit
final

This callback will be triggered when the widget is created No matter if the node is created or reused

Implementation

final void Function(N node)? onInit;