SignalBuilder<S> class

Inheritance

Constructors

SignalBuilder({Key? key, required BaseSignal<S> signal, required Widget builder(BuildContext context, S value), dynamic listener(S previousValue, S newValue)?})
const
SignalBuilder.listener({Key? key, required BaseSignal<S> signal, required dynamic listener(S previousValue, S newValue)?, required Widget builder(BuildContext context, S value)})
Use SignalListener instead.
const

Properties

builder Widget Function(BuildContext context, S value)
final
hashCode int
The hash code for this object.
no setterinherited
isListener bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listener → dynamic Function(S previousValue, S newValue)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signal BaseSignal<S>
You can choose any Node that is an ancestor of the current widget. No matter how far away it is, just make it explicit like this:
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SignalBuilder<S>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited