SignalBuilderMany<R> constructor

const SignalBuilderMany<R>({
  1. Key? key,
  2. required Set<BaseSignal> signals,
  3. required Widget builder(
    1. BuildContext context,
    2. R readable
    ),
  4. dynamic listener()?,
})

IMPORTANT!!

Even though you have access to all signals in the node through the readable the widget will only rebuild when one of the signals in the list changes.

This widget was created for cases where you need to listen to many (more than 2) signals. We strongly recommend you to use SignalBuilder instead if you only need to listen to one or two signals.

Implementation

const SignalBuilderMany({
  super.key,
  required this.signals,
  required this.builder,
  this.listener,
});