BaseSignal<T> class
abstract
Internal base class containing the "raw" state and stream logic. Signal extends this, but ReadableSignal only wraps it.
- Implementers
Constructors
- BaseSignal(T _value)
Properties
- attachedNode ↔ Node
-
latefinal
-
controller
→ StreamController<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
T> -
no setter
-
streamTriggerImmediatly
→ Stream<
T> -
no setter
- unsafeValue ↔ T
-
getter/setter pair
- value → T
-
no setter
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited