TransformBridgeSignal<N extends NodeInterface, S, V> class

A bridge that transforms a parent signal's value into a different type.

N is the parent node type. S is the source signal type. V is the transformed value type (can differ from S, value is nullable).

late final order = registerSignal(
  TransformBridgeSignal(
    select: (OrdersNode node) => node.orders,
    transform: (orders) => orders.firstWhereOrNull((o) => o.id == id),
    update: (node, value) {
      if (value == null) return;
      node.updateOrder(value);
    },
  ),
);
Inheritance

Constructors

TransformBridgeSignal({required Signal<S> select(N node), required V transform(S value), void update(N node, V? value)?})

Properties

attachedNode Node
latefinalinherited
controller StreamController<V?>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
readable ReadableSignal<V?>
This is the readable public exposed signal. It is created by the Signal constructor and is used to access the signal's value and stream.
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<V?>
no setterinherited
streamTriggerImmediatly Stream<V?>
no setterinherited
unsafeValue ↔ V?
getter/setter pairinherited
value ↔ V?
getter/setter pairinherited-getteroverride-setter

Methods

connect(InheritedTrinityScope scope) → void
override
dispose() → void
override
emit(V? newValue) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited