FutureSignal<T> class
- Inheritance
-
- Object
- BaseSignal<
AsyncData< T> > - Signal<
AsyncData< T> > - FutureSignal
Constructors
-
FutureSignal(Future<
T> _future)
Properties
- attachedNode ↔ Node
-
latefinalinherited
-
controller
→ StreamController<
AsyncData< T> > -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
readable
→ ReadableSignal<
AsyncData< T> > -
This is the readable public exposed signal.
It is created by the Signal constructor and is used to access the signal's value and stream.
latefinalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
AsyncData< T> > -
no setterinherited
-
streamTriggerImmediatly
→ Stream<
AsyncData< T> > -
no setterinherited
-
unsafeValue
↔ AsyncData<
T> -
getter/setter pairinherited
-
value
↔ AsyncData<
T> -
getter/setter pairinherited
Methods
-
dispose(
) → void -
inherited
-
emit(
AsyncData< T> newValue) → void -
inherited
-
fetch(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
W> ({required W builder(AsyncData< T> value), required W loading(), required W error(AsyncError<T> value)}) → W
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited