ReadableSignal<T> class
This class is just a read-only "view". It does NOT extend BaseSignal to avoid inheriting internal behaviors, acting instead as a proxy to the original signal.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ BaseSignal<
T> -
no setter
-
stream
→ Stream<
T> -
no setter
-
streamTriggerImmediatly
→ Stream<
T> -
no setter
- value → T
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override