Node class abstract

The base class for all nodes.

It is used to create nodes that can be used to store data and perform actions.

If you want a more complete node you can use NodeInterface.

Implementers

Constructors

Node({required Key? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
initialized bool
no setter
key Key?
final
readable → dynamic
This is the readable version of the node It is used to access the signals of the node directly by its value.
no setter
runtimeKey Key
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(InheritedTrinityScope scope) bool
Returns true if the node was previously initialized, false otherwise
dispose() → void
Método interno llamado por el framework para limpiar recursos
isSignalRegistered(BaseSignal signal) bool
We use this to improve optimization
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → void
Cuando el NodeProvider se desmonta
onInit() → void
Primer punto de entrada, el scope ya está disponible
onReady() → void
Después del primer frame, contexto de UI listo
registerManyBridges(List<BaseBridgeSignal> bridges) → void
registerSignal<S extends BaseSignal>(S signal) → S
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited