attach method
Returns true if the node was previously initialized, false otherwise
Implementation
bool attach(InheritedTrinityScope scope) {
assert(
!_initialized,
'Node already initialized. If you want to reuse it, set the reuse parameter of your NodeProvider to true.',
);
_scope = scope; //*
for (final bridge in _bridges) {
bridge.connect(scope); // busca el Node B y se suscribe
}
_initialized = true;
return true;
}