readable property
This is the readable version of the node It is used to access the signals of the node directly by its value.
You will use it for the ManySignalBuilder
In order to use it you need to generate it with
build_runner and the value should be
ReadableYourNode get readable => ReadableYourNode(this)
Implementation
@protected
dynamic get readable => null;