BoolSignal class
- Inheritance
-
- Object
- ChangeNotifier
- BaseSignal<
bool> - Signal<
bool> - BoolSignal
Constructors
- BoolSignal(bool value)
- BoolSignal.deferred()
Properties
- attachedNode ↔ Node
-
latefinalinherited
-
controller
→ StreamController<
bool> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasValue → bool
-
True if the signal has a value assigned.
no setterinherited
- isDisposed → bool
-
Returns true if this signal has already been disposed.
no setterinherited
- isFalse → bool
-
no setter
- isTrue → bool
-
no setter
-
readable
→ ReadableSignal<
bool> -
This is the readable public exposed signal.
It is created by the Signal constructor and is used to access the signal's value and stream.
latefinalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
bool> -
no setterinherited
-
streamTriggerImmediatly
→ Stream<
bool> -
no setterinherited
- unsafeValue ↔ bool
-
getter/setter pairinherited
- value ↔ bool
-
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
emit(
bool newValue) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toggle(
) → void - Toggle the value of the signal
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited