BoolSignal class

Inheritance

Constructors

BoolSignal(bool value)
BoolSignal.deferred()

Properties

attachedNode Node
latefinalinherited
controller StreamController<bool>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
True if the signal has a value assigned.
no setterinherited
isDisposed bool
Returns true if this signal has already been disposed.
no setterinherited
isFalse bool
no setter
isTrue bool
no setter
readable ReadableSignal<bool>
This is the readable public exposed signal. It is created by the Signal constructor and is used to access the signal's value and stream.
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<bool>
no setterinherited
streamTriggerImmediatly Stream<bool>
no setterinherited
unsafeValue bool
getter/setter pairinherited
value bool
getter/setter pairinherited

Methods

dispose() → void
inherited
emit(bool newValue) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggle() → void
Toggle the value of the signal
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited