ProtectedSignal<T> class
A signal that can be read from the outside, but can only be modified from the inside. It is used to wrap signals that are not meant to be modified by the outside world.
- Inheritance
-
- Object
- ChangeNotifier
- BaseSignal<
T> - ProtectedSignal
- Implementers
Constructors
- ProtectedSignal(T value)
- ProtectedSignal.deferred()
Properties
- attachedNode ↔ Node
-
latefinalinherited
-
controller
→ StreamController<
T> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasValue → bool
-
True if the signal has a value assigned.
no setterinherited
- isDisposed → bool
-
Returns true if this signal has already been disposed.
no setterinherited
-
readable
→ ReadableSignal<
T> -
This is the readable public exposed signal.
It is created by the Signal constructor and is used to access the signal's value and stream.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
T> -
no setterinherited
-
streamTriggerImmediatly
→ Stream<
T> -
no setterinherited
- unsafeValue ↔ T
-
getter/setter pairinherited
- value ↔ T
-
getter/setter pairinherited-getter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
emit(
T newValue) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited