signal property
You can choose any Node that is an ancestor of the current widget. No matter how far away it is, just make it explicit like this:
SignalBuilder(
signal: node.yourSignal,
builder: (context, value) {
return Text(value);
},
)
Implementation
final BaseSignal<S> signal;