SignalBuilderMany<R> constructor
const
SignalBuilderMany<R> ({
- Key? key,
- required Set<
BaseSignal> signals, - required Widget builder(
- BuildContext context,
- R readable
- dynamic listener()?,
IMPORTANT!!
Even though you have access to all signals in the node through the readable
the widget will only rebuild when one of the signals in the list changes.
This widget was created for cases where you need to listen to many (more than 2) signals. We strongly recommend you to use SignalBuilder instead if you only need to listen to one or two signals.
Implementation
const SignalBuilderMany({
super.key,
required this.signals,
required this.builder,
this.listener,
});